@@ -2,8 +2,6 @@
 Box module.
 """
 
-import sys
-
 
 def create_box(boxtype,
                **kwargs):
@@ -63,8 +61,11 @@ def create_box(boxtype,
     elif boxtype == 'photometry':
         box = PhotometryBox()
         box.name = kwargs['name']
+        box.sptype = kwargs['sptype']
         box.wavelength = kwargs['wavelength']
         box.flux = kwargs['flux']
+        box.app_mag = kwargs['app_mag']
+        box.abs_mag = kwargs['abs_mag']
 
     elif boxtype == 'residuals':
         box = ResidualsBox()
@@ -108,22 +109,22 @@ class Box:
         """
         Returns
         -------
-        None
+        NoneType
+            None
         """
 
     def open_box(self):
         """
         Returns
         -------
-        None
+        NoneType
+            None
         """
 
-        sys.stdout.write(f'Opening {type(self).__name__}...\n')
-        sys.stdout.flush()
+        print(f'Opening {type(self).__name__}...')
 
-        for item in self.__dict__.keys():
-            sys.stdout.write(str(item)+' = '+str(self.__dict__[item])+'\n')
-            sys.stdout.flush()
+        for key, value in self.__dict__.items():
+            print(f'{key} = {value}')
 
 
 class ColorMagBox(Box):
@@ -135,7 +136,8 @@ class ColorMagBox(Box):
         """
         Returns
         -------
-        None
+        NoneType
+            None
         """
 
         self.library = None
@@ -156,7 +158,8 @@ class ColorColorBox(Box):
         """
         Returns
         -------
-        None
+        NoneType
+            None
         """
 
         self.library = None
@@ -176,7 +179,8 @@ class IsochroneBox(Box):
         """
         Returns
         -------
-        None
+        NoneType
+            None
         """
 
         self.model = None
@@ -198,7 +202,8 @@ class ModelBox(Box):
         """
         Returns
         -------
-        None
+        NoneType
+            None
         """
 
         self.model = None
@@ -218,7 +223,8 @@ class ObjectBox(Box):
         """
         Returns
         -------
-        None
+        NoneType
+            None
         """
 
         self.name = None
@@ -238,12 +244,16 @@ class PhotometryBox(Box):
         """
         Returns
         -------
-        None
+        NoneType
+            None
         """
 
         self.name = None
+        self.sptype = None
         self.wavelength = None
         self.flux = None
+        self.app_mag = None
+        self.abs_mag = None
 
 
 class ResidualsBox(Box):
@@ -255,7 +265,8 @@ class ResidualsBox(Box):
         """
         Returns
         -------
-        None
+        NoneType
+            None
         """
 
         self.name = None
@@ -272,7 +283,8 @@ class SamplesBox(Box):
         """
         Returns
         -------
-        None
+        NoneType
+            None
         """
 
         self.spectrum = None
@@ -291,7 +303,8 @@ class SpectrumBox(Box):
         """
         Returns
         -------
-        None
+        NoneType
+            None
         """
 
         self.spectrum = None
@@ -313,7 +326,8 @@ class SynphotBox(Box):
         """
         Returns
         -------
-        None
+        NoneType
+            None
         """
 
         self.name = None
