@@ -40,25 +40,29 @@ def download_filter(filter_id):
 
         wget.download(url, out='filter.dat', bar=None)
 
-        wavelength, transmission = np.loadtxt('filter.dat', unpack=True)
+        if os.stat('filter.dat').st_size == 0:
+            raise ValueError(f'Filter {filter_id} not found on the SVO Filter Profile Service.')
 
-        wavelength *= 1e-4  # [micron]
+        else:
+            wavelength, transmission = np.loadtxt('filter.dat', unpack=True)
+            wavelength *= 1e-4  # [micron]
 
         os.remove('filter.dat')
 
-    indices = []
+    if wavelength is not None:
+        indices = []
 
-    for i in range(transmission.size):
-        if i == 0 and transmission[i] == 0. and transmission[i+1] == 0.:
-            indices.append(i)
+        for i in range(transmission.size):
+            if i == 0 and transmission[i] == 0. and transmission[i+1] == 0.:
+                indices.append(i)
 
-        elif i == transmission.size-1 and transmission[i-1] == 0. and transmission[i] == 0.:
-            indices.append(i)
+            elif i == transmission.size-1 and transmission[i-1] == 0. and transmission[i] == 0.:
+                indices.append(i)
 
-        elif transmission[i-1] == 0. and transmission[i] == 0. and transmission[i+1] == 0.:
-            indices.append(i)
+            elif transmission[i-1] == 0. and transmission[i] == 0. and transmission[i+1] == 0.:
+                indices.append(i)
 
-    wavelength = np.delete(wavelength, indices)
-    transmission = np.delete(transmission, indices)
+        wavelength = np.delete(wavelength, indices)
+        transmission = np.delete(transmission, indices)
 
     return wavelength, transmission
